<?php

/***
	Esta classe é responsável por fazer todas as consultas do Adwords.
 ***/

require_once(__DIR__ . '/../../../vendor/autoload.php');

use Google\AdsApi\AdWords\AdWordsServices;
use Google\AdsApi\AdWords\AdWordsSession;
use Google\AdsApi\AdWords\AdWordsSessionBuilder;
use Google\AdsApi\AdWords\v201809\cm\AdGroupService;
use Google\AdsApi\AdWords\Reporting\v201809\DownloadFormat;
use Google\AdsApi\AdWords\Reporting\v201809\ReportDefinition;
use Google\AdsApi\AdWords\Reporting\v201809\ReportDefinitionDateRangeType;
use Google\AdsApi\AdWords\Reporting\v201809\ReportDownloader;
use Google\AdsApi\AdWords\ReportSettingsBuilder;
use Google\AdsApi\AdWords\v201809\cm\Paging;
use Google\AdsApi\AdWords\v201809\cm\OrderBy;
use Google\AdsApi\AdWords\v201809\cm\SortOrder;
use Google\AdsApi\AdWords\v201809\cm\DateRange;
use Google\AdsApi\AdWords\v201809\cm\Predicate;
use Google\AdsApi\AdWords\v201809\cm\PredicateOperator;
use Google\AdsApi\AdWords\v201809\cm\ReportDefinitionReportType;
use Google\AdsApi\AdWords\v201809\cm\Selector;
use Google\AdsApi\Common\OAuth2TokenBuilder;
use Google\AdsApi\AdWords\v201809\cm\CampaignService;
use Google\AdsApi\AdWords\v201809\cm\CampaignCriterionService;
use Google\AdsApi\AdWords\v201809\cm\IpBlock;
use Google\AdsApi\AdWords\v201809\cm\NegativeCampaignCriterion;
use Google\AdsApi\AdWords\v201809\cm\Operator;
use Google\AdsApi\AdWords\v201809\cm\Campaign;
use Google\AdsApi\AdWords\v201809\cm\CampaignCriterion;
use Google\AdsApi\AdWords\v201809\cm\CampaignOperation;
use Google\AdsApi\AdWords\v201809\cm\CampaignStatus;
use Google\AdsApi\AdWords\v201809\cm\CampaignCriterionOperation;
use Google\AdsApi\AdWords\v201809\cm\CriterionType;
use Google\AdsApi\AdWords\v201809\cm\ApiException;
use Detection\MobileDetect;

class Sistema_Adwords
{
	private $bd;

	const PAUSAR = 0;
	const RESUMIR = 1;

	function __construct(&$bd)
	{
		$this->bd = $bd;
	}

	/* Retorna a versão do adwords sendo usada atualmente */
	static function versao_adwords()
	{
		return 'v201809';
	}

	/* Trata alguma exceção ocorrida */
	function tratar_excecao($exception)
	{
		if ($exception instanceof ApiException) {
			foreach ($exception->getErrors() as $error) {
				if ($error->getErrorString() == "AuthorizationError.USER_PERMISSION_DENIED") {
					echo "-2Permissão Negada.";
					exit;
				}
				if ($error->getErrorString() == "DateError.DATE_RANGE_MINIMUM_DATE_LATER_THAN_MAXIMUM_DATE") {
					echo "-2Data inicial maior do que a data final, inverta as datas.";
					exit;
				}
			}
			// echo var_dump($exception->getErrors());
			echo "-2Houve um erro com o servidor. #1";
			exit;
		} else {
			// echo var_dump($exception->getErrors());
			echo "-2Houve um erro com o servidor. #2";
			exit;
		}
	}

	/* Função que bloqueia um IP em todas as campanhas de um certo cliente com certa ID. */
	function bloquear_ip($id, $ip)
	{
		// Consultamos primeiro qual a ID do adwords do cliente
		$dados = $this->bd->executar("SELECT NU_ADWORDS FROM TBL_CLIENTE WHERE ID_CLIENTE = :id", array(':id' => $id), Banco_Dados::FETCH);
		$id_do_adwords = $dados['NU_ADWORDS'];

		// Agora cria-se o objeto de usuário que será usado nas consultas
		$credenciais = $this->obter_credenciais($id_do_adwords);
		$services = new AdWordsServices();

		// Consulta-se quais são todas as campanhas do cliente especificado
		$campanhas = $this->listar_campanhas($credenciais, $services);

		// Agora, bloqueia-se o IP especificado em todas as campanhas.
		$this->bloquear_ip_nas_campanhas($campanhas, $credenciais, $ip, $services);
	}

	// Função que muda o status da campanha para habilitada ou pausada
	function mudar_status_campanha($id_campanha, $id_cliente, $status)
	{
		// Consultamos primeiro qual a ID do adwords do cliente
		$dados = $this->bd->executar("SELECT NU_ADWORDS FROM TBL_CLIENTE WHERE ID_CLIENTE = :id", array(':id' => $id_cliente), Banco_Dados::FETCH);
		$id_do_adwords = $dados['NU_ADWORDS'];

		// Agora cria-se o objeto de usuário que será usado nas consultas
		$credenciais = $this->obter_credenciais($id_do_adwords);
		$services = new AdWordsServices();

		$campaignService = $services->get($credenciais->sessao, CampaignService::class);

		$status = ($status == self::PAUSAR) ? CampaignStatus::PAUSED : CampaignStatus::ENABLED;
		$operations = array();

		$campaign = new Campaign();
		$campaign->setId($id_campanha);
		$campaign->setStatus($status);

		$operation = new CampaignOperation();
		$operation->setOperand($campaign);
		$operation->setOperator(Operator::SET);
		$operations[] = $operation;

		$result = $campaignService->mutate($operations);
	}

	/* Função que faz uma consulta no adwords para listar todas as campanhas de um cliente */
	function listar_campanhas($credenciais, $services)
	{
		$campaignService = $services->get($credenciais->sessao, CampaignService::class);

		$selector = new Selector();
		$selector->setFields(['Id', 'Name']);
		$selector->setOrdering([new OrderBy('Name', SortOrder::ASCENDING)]);
		$selector->setPaging(new Paging(0, 5000));
		$selector->setPredicates([new Predicate('CampaignStatus', 'IN', array('ENABLED'))]);

		$campanhas = array();
		$totalNumEntries = 0;
		do {
			$page = $campaignService->get($selector);

			if ($page->getEntries() !== null) {
				$totalNumEntries = $page->getTotalNumEntries();
				foreach ($page->getEntries() as $campaign) {
					$campanhas[] = array(
						"id" => $campaign->getId(),
						"nome" => $campaign->getName()
					);
				}
			}

			$selector->getPaging()->setStartIndex(
				$selector->getPaging()->getStartIndex() + 5000
			);
		} while ($selector->getPaging()->getStartIndex() < $totalNumEntries);

		return $campanhas;
	}

	/* Função que bloqueia um certo IP nas campanhas especificadas */
	function bloquear_ip_nas_campanhas($campanhas, $credenciais, $ip, $services)
	{
		$campaignCriterionService = $services->get($credenciais->sessao, CampaignCriterionService::class);

		$operations = array();

		$IpBlock = new IpBlock();
		$IpBlock->setIpAddress($ip);

		foreach ($campanhas as $campanha) {
			$negativeCriterion = new NegativeCampaignCriterion();
			$negativeCriterion->setCampaignId($campanha['id']);
			$negativeCriterion->setCriterion($IpBlock);

			$operation = new CampaignCriterionOperation();
			$operation->setOperator(Operator::ADD);
			$operation->setOperand($negativeCriterion);

			$operations[] = $operation;
		}

		$result = $campaignCriterionService->mutate($operations);
	}

	/* Obtém as credenciais e a sessão adwords para o cliente com a id especificada */
	function obter_credenciais($adwords)
	{
		$credenciais = new Credenciais_Adwords();

		$oAuth2Credential = (new OAuth2TokenBuilder())
			->fromFile("/home/pages/adsapi_php.ini")
			->build();

		$session = (new AdWordsSessionBuilder())
			->fromFile("/home/pages/adsapi_php.ini")
			->withOAuth2Credential($oAuth2Credential)->withClientCustomerId($adwords)
			->build();

		$credenciais->oauth2 = $oAuth2Credential;
		$credenciais->sessao = $session;

		return $credenciais;
	}

	/* Faz uma consulta comum no adwords */
	function consulta_adwords($adwords, $fields, $report_type, $data, $inicial, $final, $predicates, $format, $zero_impressions = FALSE)
	{
		$credenciais = $this->obter_credenciais($adwords);

		$selector = new Selector();
		$selector->setFields($fields);
		if (count($predicates) > 0) $selector->setPredicates($predicates);

		if ($data == "CUSTOM_DATE" && !empty($inicial) && !empty($final)) {
			$dtInicial   = $inicial;
			$dtInicial   = str_replace(array('%2F'), '/', $dtInicial);
			$dtInicial   = str_replace(array('/'), '-', $dtInicial);
			$dtInicial   = new DateTime($dtInicial);
			$dtInicial   = $dtInicial->format('Ymd');

			$dtFinal   = $final;
			$dtFinal   = str_replace(array('%2F'), '/', $dtFinal);
			$dtFinal   = str_replace(array('/'), '-', $dtFinal);
			$dtFinal   = new DateTime($dtFinal);
			$dtFinal   = $dtFinal->format('Ymd');

			$selector->setDateRange(new DateRange($dtInicial, $dtFinal));
		}

		$reportDefinition = new ReportDefinition();
		$reportDefinition->setReportName('Consulta de performance adwords de ID #' . uniqid());
		switch ($data) {
			case "LAST_7_DAYS_TODAY":
				$start_week = strtotime("-7 days");
				$end_week = time();
				$start_week = date("Ymd", $start_week);
				$end_week = date("Ymd", $end_week);
				$selector->setDateRange(new DateRange($start_week, $end_week));
				$reportDefinition->setSelector($selector);
				$reportDefinition->setDateRangeType("CUSTOM_DATE");
				break;
			case "LAST_14_DAYS_TODAY":
				$start_week = strtotime("-14 days");
				$end_week = time();
				$start_week = date("Ymd", $start_week);
				$end_week = date("Ymd", $end_week);
				$selector->setDateRange(new DateRange($start_week, $end_week));
				$reportDefinition->setSelector($selector);
				$reportDefinition->setDateRangeType("CUSTOM_DATE");
				break;
			case "LAST_30_DAYS_TODAY":
				$start_week = strtotime("-30 days");
				$end_week = time();
				$start_week = date("Ymd", $start_week);
				$end_week = date("Ymd", $end_week);
				$selector->setDateRange(new DateRange($start_week, $end_week));
				$reportDefinition->setSelector($selector);
				$reportDefinition->setDateRangeType("CUSTOM_DATE");
				break;
			default:
				$reportDefinition->setSelector($selector);
				$reportDefinition->setDateRangeType($data);
		}

		$reportDefinition->setReportType($report_type);
		$reportDefinition->setDownloadFormat($format);

		$reportDownloader = new ReportDownloader($credenciais->sessao);
		$reportSettingsOverride = (new ReportSettingsBuilder())->includeZeroImpressions($zero_impressions)->build();
		$reportDownloadResult = $reportDownloader->downloadReport($reportDefinition, $reportSettingsOverride);

		return $reportDownloadResult->getAsString();
	}

	/* Função que retorna todos os grupos de anúncios do cliente */
	function grupos_adwords($adwords_id, $modo_campanha = false, $campanhas_visiveis = null)
	{

		// ESSA PARTE PEGA TODAS AS CAMPANHAS QUE ESTÃO ATIVAS E NÃO FINALIZADAS
		// ESSA LÓGICA É APENAS PARA FILTRAR E NÃO LISTAR CAMPANHAS EXPERIMENTAIS
		$credenciais = $this->obter_credenciais($adwords_id);

		$services = new AdWordsServices();
		$campaignService = $services->get($credenciais->sessao, CampaignService::class);

		// Create selector.
		$selector = new Selector();
		$selector->setFields(['Id']);
		$selector->setOrdering([new OrderBy('Id', SortOrder::ASCENDING)]);
		$selector->setPaging(new Paging(0, 5000));

		$predicados = [
			new Predicate('CampaignStatus', PredicateOperator::IN, ['ENABLED']),
			// ESSE PREDICADO ABAIXO ELIMITA AS CAMPANHAS FINALIZADAS
			// POR ISSO ELA ELIMINA AS CAMPANHAS EXPERIMENTAIS FINALIZADAS
			new Predicate('ServingStatus', PredicateOperator::IN, ['SERVING']),
		];

		$selector->setPredicates($predicados);

		$campanhasIDs = array();
		$totalNumEntries = 0;
		do {
			// Make the get request.
			$page = $campaignService->get($selector);

			// Display results.
			if ($page->getEntries() !== null) {
				$totalNumEntries = $page->getTotalNumEntries();
				foreach ($page->getEntries() as $campaign) {	
					$campanhasIDs[] = $campaign->getId();
				}
			}

			// Advance the paging index.
			$selector->getPaging()->setStartIndex($selector->getPaging()->getStartIndex() + 5000);
		} while ($selector->getPaging()->getStartIndex() < $totalNumEntries);


		// ESSA PARTE JÁ BUSCAS TODAS OS GRUPOS DE ANUNCIOS DAS CAMPANHAS LISTADAS ACIMA OU JÁ CONFIGURADAS NO SISTEMAS WIN7
		$services = new AdWordsServices();
		$adGroupService = $services->get($credenciais->sessao, AdGroupService::class);

		$selector = new Selector();
		$selector->setFields(['Id', 'Name', 'CampaignId', 'CampaignName']);
		$selector->setOrdering([new OrderBy('Name', SortOrder::ASCENDING)]);
		$selector->setPaging(new Paging(0, 5000));

		$predicados = [
			new Predicate('AdGroupStatus', PredicateOperator::IN, ['ENABLED']),
			new Predicate('CampaignStatus', PredicateOperator::IN, ['ENABLED']),
		];

		// SE O SISTEMAWIN7 ESTIVER CONFIGURADO PARA BUSCAR AS CAMPANHAS CONFIGURADAS NELE ENTRA NO IF
		// SE NÃO TIVER NADA CONFIGURADO, BUSCA TODAS AS CAMPANHAS LISTADAS NA ETAPA ANTERIOR ACIMA
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		} else {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhasIDs);
		}

		$selector->setPredicates($predicados);

		$grupos = array();
		$totalNumEntries = 0;
		do {
			$page = $adGroupService->get($selector);

			if ($page->getEntries() !== null) {
				$totalNumEntries = $page->getTotalNumEntries();

				foreach ($page->getEntries() as $adGroup) {
					$grupos[] = array(
						"nome" => $adGroup->getName(),
						"id" => $adGroup->getId(),
						"campanhaId" => $adGroup->getCampaignId(),
						"campanhaNome" => $adGroup->getCampaignName(),
					);
				}
			}

			$selector->getPaging()->setStartIndex($selector->getPaging()->getStartIndex() + 5000);
		} while ($selector->getPaging()->getStartIndex() < $totalNumEntries);

		return $grupos;
	}

	/* Faz uma consulta básica de desempenho geral da conta do adwords especificada */
	function desempenho_da_conta($id_adwords, $display, $filtro, $data_inicial, $data_final, $modo_campanha = false, $campanhas_visiveis = null)
	{
		$campos = ['AverageCpc', 'Cost', 'Ctr', 'ConversionRate', 'Conversions', 'CostPerConversion', 'Clicks', 'Impressions', 'InvalidClicks', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage'];
		$predicados = array();
		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);

			/* Adiciona as metricas de Impressions no final do array de metricas tradicionais acima */
			// array_push($campos, 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		$report_type = $modo_campanha === true ? ReportDefinitionReportType::CAMPAIGN_PERFORMANCE_REPORT : ReportDefinitionReportType::ACCOUNT_PERFORMANCE_REPORT;

		$report = $this->consulta_adwords($id_adwords, $campos, $report_type, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);
		$xml = new SimpleXMLElement(gzdecode($report));

		$rows = $xml->xpath('/report/table/row');
		return $rows;
	}

	/* Faz a consulta dos dados do gráfico geral */
	function resultado_geral($id_adwords, $filtro, $data_inicial, $data_final)
	{
		$campos = ['Clicks'];
		$predicados = array();
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::ACCOUNT_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);
		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');
		return $rows;
	}

	/* Faz a consulta das palavras-chave do cliente */
	function consultar_palavras_cliente($id_adwords, $consultoria, $display, $grupo, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null)
	{
		if ($consultoria) { // Caso o cliente seja de consultoria, adicionamos os campos custo e cpc
			$campos = array('Criteria', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AdGroupId', 'AdGroupName', 'CampaignName', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage', 'AverageCpc', 'Cost');
		} else {
			$campos = array('Criteria', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AdGroupId', 'AdGroupName', 'CampaignName', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		// Montamos aqui os predicados
		$predicados = array();

		$predicados[] = new Predicate('Status', PredicateOperator::IN, ['ENABLED']);
		$predicados[] = new Predicate('Clicks', PredicateOperator::GREATER_THAN, [0]);

		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);

		if (!empty($grupo) & ctype_digit($grupo) & $grupo != "todos") {
			$predicados[] = new Predicate('AdGroupId', PredicateOperator::IN, [$grupo]);
		}
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		}

		// Fazemos a consulta do adwords
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::KEYWORDS_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Montamos aqui a array que será enviada por meio de JSON
		$resultado = array();
		foreach ($rows as $row) {
			// Removemos aqui os "+" das palavras-chave
			$keywords = str_replace("+", "", $row["keyword"]->__toString());

			if ($keywords == "Content") {
				continue;
			}

			$linha = array(
				"keyword" => $keywords,
				"impressions" => Sistema_Adwords::formatar_numero($row["impressions"]),
				"clicks" => Sistema_Adwords::formatar_numero($row["clicks"]),
				"convertedClicks" => $row["conversions"]->__toString(),
				"clickConversionRate" => $row["convRate"]->__toString(),
				"ctr" => $row["ctr"]->__toString(),
				// "avgPosition" => $row["avgPosition"]->__toString()
				"imprAbsTop" => ($row["imprAbsTop"] == "1.0") ? str_replace('.', '', $row["imprAbsTop"]) : substr($row["imprAbsTop"]->__toString(), 2),
				"imprTop" => ($row["imprTop"] == "1.0") ? str_replace('.', '', $row["imprTop"]) : substr($row["imprTop"]->__toString(), 2),
			);

			// Caso o cliente seja de consultoria, adicionamos os campos de custo e cpc
			if ($consultoria) {
				$linha["avgCPC"] = $this->formatar_valor($row["avgCPC"], $convencao);
				$linha["cost"] = $this->formatar_valor($row["cost"], $convencao);
			}
			$resultado[] = $linha;
		}

		return $resultado;
	}

	/* Faz a consulta das palavras-chave negativas do cliente */
	function consultar_palavras_negativas_cliente($id_adwords, $consultoria = null, $display, $grupo, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null, $idDaCampanhaDoGrupo)
	{

		// AQUI PEGA AS PALAVRAS CHAVE NEGATIVAS DO GRUPO DE ANUNCIO SELECIONADO
		$campos = array('Criteria', 'CampaignName', 'KeywordMatchType', 'AdGroupName', 'IsNegative');

		// Montamos aqui os predicados
		$predicados = array();

		$predicados[] = new Predicate('CampaignStatus', PredicateOperator::IN, ['ENABLED','PAUSED']);
		$predicados[] = new Predicate('Status', PredicateOperator::IN, ['ENABLED','PAUSED']);
		$predicados[] = new Predicate('IsNegative', PredicateOperator::IN, ['true']);

		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);

		if (!empty($grupo) & ctype_digit($grupo) & $grupo != "todos") {
			$predicados[] = new Predicate('AdGroupId', PredicateOperator::IN, [$grupo]);
		}
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		}

		// Fazemos a consulta do adwords
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::KEYWORDS_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Montamos aqui a array que será enviada por meio de JSON
		$resultado = array();
		foreach ($rows as $row) {
			// Removemos aqui os "+" das palavras-chave
			$keywords = str_replace("+", "", $row["keyword"]->__toString());

			if ($keywords == "Content") {
				continue;
			}

			$linha = array(
				"negativeKeyword" => $keywords,
				"matchType" => $row["matchType"]->__toString(),
				"campaign" => $row["campaign"]->__toString() . " → " . $row["adGroup"]->__toString(),
				"negativeKeywordNivel" => 'Grupo de anúncio',
			);

			$resultado[] = $linha;
		}

		// AQUI PEGA AS PALAVRAS CHAVE NEGATIVAS DA CAMPANHA DO GRUPO ACIMA
		$campos = array('Criteria', 'CampaignName', 'KeywordMatchType');

		// Montamos aqui os predicados
		$predicados = array();

		$predicados[] = new Predicate('CampaignStatus', PredicateOperator::IN, ['ENABLED','PAUSED']);
		$predicados[] = new Predicate('IsNegative', PredicateOperator::IN, ['true']);

		// Esse Report não permite o AdNetworkType1
		// if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);

		if (!empty($grupo) & ctype_digit($grupo) & $grupo != "todos") {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, [$idDaCampanhaDoGrupo]);
		} else {
			if ($modo_campanha === true && $campanhas_visiveis != null) {
				$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
			}
		}

		// Fazemos a consulta do adwords
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::CAMPAIGN_NEGATIVE_KEYWORDS_PERFORMANCE_REPORT, "ALL_TIME", $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Montamos aqui a array que será enviada por meio de JSON
		// $resultado = array();
		foreach ($rows as $row) {
			// Removemos aqui os "+" das palavras-chave
			$negativeKeyword = str_replace("+", "", $row["negativeKeyword"]->__toString());

			if ($negativeKeyword == "Content") {
				continue;
			}

			$linha = array(
				"negativeKeyword" => $negativeKeyword,
				"matchType" => $row["matchType"]->__toString(),
				"campaign" => $row["campaign"]->__toString(),
				"negativeKeywordNivel" => 'Campanha',
			);

			$resultado[] = $linha;
		}
		return $resultado;
	}

	/* Faz a consulta dos termos de pesquisa dos grupos de anuncios do cliente */
	function consultar_termos_pesquisa($id_adwords, $consultoria, $display, $grupo, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null)
	{
		if ($consultoria) { // Caso o cliente seja de consultoria, adicionamos os campos custo e cpc
			$campos = array('Query', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AdGroupId', 'AdGroupName', 'CampaignName', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage', 'AverageCpc', 'Cost');
		} else {
			$campos = array('Query', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AdGroupId', 'AdGroupName', 'CampaignName', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		// Montamos aqui os predicados
		$predicados = array();

		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);
		if (!empty($grupo) & ctype_digit($grupo) & $grupo != "todos") {
			$predicados[] = new Predicate('AdGroupId', PredicateOperator::IN, [$grupo]);
		}
		// Esse predicado abaixo nao funciona para os termos
		// $predicados[] = new Predicate('Status', PredicateOperator::IN, ['ENABLED']);

		// Para filtrar apenas termos que possuem cliques, descomente a linha abaixo
		// $predicados[] = new Predicate('Clicks', PredicateOperator::GREATER_THAN, [0]);
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		}

		// Fazemos a consulta do adwords
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::SEARCH_QUERY_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Montamos aqui a array que será enviada por meio de JSON
		$resultado = array();
		foreach ($rows as $row) {
			// Removemos aqui os "+" das palavras-chave
			$termosPesquisa = str_replace("+", "", $row["searchTerm"]->__toString());

			if ($termosPesquisa == "Content") {
				continue;
			}

			$linha = array(
				"searchTerm" => $termosPesquisa,
				"impressions" => Sistema_Adwords::formatar_numero($row["impressions"]),
				"clicks" => Sistema_Adwords::formatar_numero($row["clicks"]),
				"convertedClicks" => $row["conversions"]->__toString(),
				"clickConversionRate" => $row["convRate"]->__toString(),
				"ctr" => $row["ctr"]->__toString(),
				// "avgPosition" => $row["avgPosition"]->__toString()
				"imprAbsTop" => ($row["imprAbsTop"] == "1.0") ? str_replace('.', '', $row["imprAbsTop"]) : substr($row["imprAbsTop"]->__toString(), 2),
				"imprTop" => ($row["imprTop"] == "1.0") ? str_replace('.', '', $row["imprTop"]) : substr($row["imprTop"]->__toString(), 2),
			);

			// Caso o cliente seja de consultoria, adicionamos os campos de custo e cpc
			if ($consultoria) {
				$linha["avgCPC"] = $this->formatar_valor($row["avgCPC"], $convencao);
				$linha["cost"] = $this->formatar_valor($row["cost"], $convencao);
			}
			$resultado[] = $linha;
		}

		return $resultado;
	}

	/* Faz a consulta dos grupos de anúncio do cliente */
	function consultar_grupos_cliente($id_adwords, $consultoria, $display, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null)
	{
		if ($consultoria) { // Caso o cliente seja de consultoria, adicionamos os campos custo e cpc
			$campos = array('AdGroupId', 'AdGroupName', 'CampaignId', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage', 'AverageCpc', 'Cost');
		} else {
			$campos = array('AdGroupId', 'AdGroupName', 'CampaignId', 'ConversionRate', 'Clicks', 'Impressions', 'Conversions', 'Ctr', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		// Criamos aqui os predicados
		$predicados = array();
		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);
		$predicados[] = new Predicate('Clicks', PredicateOperator::GREATER_THAN, [0]);
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		}

		// Fazemos a consulta
		$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::ADGROUP_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Com a consulta já feita, montamos a array que será enviada por meio meio de JSON
		$resultado = array();
		foreach ($rows as $row) {
			$linha = array(
				"adGroupID" => $row["adGroupID"]->__toString(),
				"adGroup" => $row["adGroup"]->__toString(),
				"impressions" => Sistema_Adwords::formatar_numero($row["impressions"]),
				"clicks" => Sistema_Adwords::formatar_numero($row["clicks"]),
				//"convertedClicks" => Sistema_Adwords::formatar_numero($row["conversions"]),
				//"clickConversionRate" => $row["convRate"]->__toString(),
				"ctr" => $row["ctr"]->__toString(),
				// "avgPosition" => $row["avgPosition"]->__toString()
				"imprAbsTop" => ($row["imprAbsTop"] == "1.0") ? str_replace('.', '', $row["imprAbsTop"]) : substr($row["imprAbsTop"]->__toString(), 2),
				"imprTop" => ($row["imprTop"] == "1.0") ? str_replace('.', '', $row["imprTop"]) : substr($row["imprTop"]->__toString(), 2)
			);

			// Caso o cliente seja de consultoria, adicionamos os campos de custo e cpc
			if ($consultoria) {
				$linha["avgCPC"] = $this->formatar_valor($row["avgCPC"], $convencao);
				$linha["cost"] = $this->formatar_valor($row["cost"], $convencao);
			}

			$resultado[] = $linha;
		}

		return $resultado;
	}

	/* Faz a consulta dos grupos de anúncio do cliente */
	function consultar_campanhas_cliente($id_adwords, $consultoria, $display, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null, $permissao_pausar_campanhas = 0)
	{
		if ($consultoria) { // Caso o cliente seja de consultoria, adicionamos os campos custo e cpc
			$campos = array('CampaignName', 'CampaignId', 'CampaignStatus', 'ConversionRate', 'Clicks', 'InvalidClicks', 'Impressions', 'Conversions', 'Ctr', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage', 'AverageCpc', 'Cost');
		} else {
			$campos = array('CampaignName', 'CampaignId', 'CampaignStatus', 'ConversionRate', 'Clicks', 'InvalidClicks', 'Impressions', 'Conversions', 'Ctr', 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		// Criamos aqui os predicados
		$predicados = array();
		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);
		
		// Verifica se a opção de mostras apenas campanhas informadas está ativa e se possue campanhas informadas
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);
		}

		// Se o cliente tiver a permissão de Pausar/Ativar campanhas, o sistema vai mostrar campanhas com zero impressoes, as ativas e pausadas
		if ($permissao_pausar_campanhas == '1') {
			
			// Filtro para mostrar as campanhas ativas e pausadas
			$predicados[] = new Predicate('CampaignStatus', PredicateOperator::IN, ['ENABLED', 'PAUSED']);

			// Filtro para mostrar as campanhas normais e evitar as campanhas de experiência
			// $predicados[] = new Predicate('CampaignTrialType', PredicateOperator::IN, ['BASE']);

			// Fazemos a consulta
			$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::CAMPAIGN_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML, true);

		} else {
			
			// Filtro para mostrar as campanhas normais e evitar as campanhas de experiência
			// $predicados[] = new Predicate('CampaignTrialType', PredicateOperator::IN, ['BASE']);

			// Fazemos a consulta
			$report = $this->consulta_adwords($id_adwords, $campos, ReportDefinitionReportType::CAMPAIGN_PERFORMANCE_REPORT, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML);

		}
		
		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		// Com a consulta já feita, montamos a array que será enviada por meio meio de JSON
		$resultado = array();
		foreach ($rows as $row) {
			$linha = array(
				"campaign" => $row["campaign"]->__toString(),
				"impressions" => Sistema_Adwords::formatar_numero($row["impressions"]),
				"clicks" => Sistema_Adwords::formatar_numero($row["clicks"]),
				//"convertedClicks" => Sistema_Adwords::formatar_numero($row["conversions"]),
				//"clickConversionRate" => $row["convRate"]->__toString(),
				"ctr" => $row["ctr"]->__toString(),
				// "avgPosition" => $row["avgPosition"]->__toString(),
				"imprAbsTop" => ($row["imprAbsTop"] == "1.0") ? str_replace('.', '', $row["imprAbsTop"]) : substr($row["imprAbsTop"]->__toString(), 2),
				"imprTop" => ($row["imprTop"] == "1.0") ? str_replace('.', '', $row["imprTop"]) : substr($row["imprTop"]->__toString(), 2),
				"invalid" => Sistema_Adwords::formatar_numero($row["invalidClicks"]),
				"paused" => $row["campaignState"]->__toString() == "paused" ? "t" : "f",
				"campaignID" => $row["campaignID"]->__toString(),
				"campaignState" => $row["campaignState"]->__toString(),
			);

			// Caso o cliente seja de consultoria, adicionamos os campos de custo e cpc
			if ($consultoria) {
				$linha["avgCPC"] = $this->formatar_valor($row["avgCPC"], $convencao);
				$linha["cost"] = $this->formatar_valor($row["cost"], $convencao);
			}

			$resultado[] = $linha;
		}

		return $resultado;
	}

	function consultar_dados_grafico($consultoria, $periodo, $display, $id_adwords, $filtro, $data_inicial, $data_final, $convencao = 0, $modo_campanha = false, $campanhas_visiveis = null)
	{
		/* Decidimos aqui os campos a serem pesquisados no adwords baseado na frequência dos dados */
		switch ($periodo) {
			case 'semanalmente':
				if ($consultoria) // Adiciona custo e cpc se o cliente for de consultoria
					$campos = array('Week', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions', 'AverageCpc', 'Cost');
				else
					$campos = array('Week', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions');
				break;

			case 'mensalmente':
				if ($consultoria) // Adiciona custo e cpc se o cliente for de consultoria
					$campos = array('Month', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions', 'AverageCpc', 'Cost');
				else
					$campos = array('Month', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions');
				break;

			default:
				if ($consultoria) // Adiciona custo e cpc se o cliente for de consultoria
					$campos = array('Date', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions', 'AverageCpc', 'Cost');
				else
					$campos = array('Date', 'AveragePosition', 'Ctr', 'ConversionRate', 'Conversions', 'Clicks', 'InvalidClicks', 'Impressions');
				break;
		}

		// Montamos os predicados
		$predicados = array();
		if (!$display) $predicados[] = new Predicate('AdNetworkType1', PredicateOperator::IN, ['SEARCH']);
		if ($modo_campanha === true && $campanhas_visiveis != null) {
			$predicados[] = new Predicate('CampaignId', PredicateOperator::IN, $campanhas_visiveis);

			/* Adiciona as metricas de Impressions no final do array de metricas tradicionais acima */
			// array_push($campos, 'AbsoluteTopImpressionPercentage', 'TopImpressionPercentage');
		}

		$report_type = $modo_campanha === true ? ReportDefinitionReportType::CAMPAIGN_PERFORMANCE_REPORT : ReportDefinitionReportType::ACCOUNT_PERFORMANCE_REPORT;

		// Fazemos a consulta do adwords
		$report = $this->consulta_adwords($id_adwords, $campos, $report_type, $filtro, $data_inicial, $data_final, $predicados, DownloadFormat::GZIPPED_XML, TRUE);

		$xml = new SimpleXMLElement(gzdecode($report));
		$rows = $xml->xpath('/report/table/row');

		$resultado = array();

		if ($modo_campanha === true) {
			foreach ($rows as $row) {
				if ($periodo == "semanalmente")
					$periodo_data = $row["week"]->__toString();
				else if ($periodo == "mensalmente")
					$periodo_data = $row["month"]->__toString();
				else
					$periodo_data = $row["day"]->__toString();

				if (!array_key_exists($periodo_data, $resultado)) {
					$resultado[$periodo_data] = array(
						"impressions" => 0,
						"clicks" => 0,
						"invalid" => 0,
						"convertedClicks" => 0,
						"convRate" => 0.0,
						"ctr" => 0.0,
						// "avgPosition" => 0.0,
						// "imprTop" => 0.0,
						// "imprAbsTop" => 0.0,
						"qtd" => 0
					);
					if ($consultoria) {
						$resultado[$periodo_data]['avgCPC'] = 0.0;
						$resultado[$periodo_data]['cost'] = 0.0;
					}
				}
				$resultado[$periodo_data]["qtd"] = $resultado[$periodo_data]["qtd"] + 1;
				$resultado[$periodo_data]["impressions"] += intval($row["impressions"]->__toString());
				$resultado[$periodo_data]["clicks"] += intval($row["clicks"]->__toString());
				$resultado[$periodo_data]["invalidClicks"] += intval($row["invalidClicks"]->__toString());
				$resultado[$periodo_data]["convertedClicks"] += intval($row["conversions"]->__toString());
				$resultado[$periodo_data]["convRate"] += floatval(str_replace("%", "", $row["convRate"]->__toString()));
				$resultado[$periodo_data]["ctr"] += floatval(str_replace("%", "", $row["ctr"]->__toString()));
				// $resultado[$periodo_data]["avgPosition"] += floatval($row["avgPosition"]->__toString());
				// $resultado[$periodo_data]["imprTop"] += floatval($row["imprTop"]->__toString());
				// $resultado[$periodo_data]["imprAbsTop"] += floatval($row["imprAbsTop"]->__toString());



				if ($consultoria) {
					$resultado[$periodo_data]["avgCPC"] += intval($row["avgCPC"]->__toString());
					$resultado[$periodo_data]["cost"] += intval($row["cost"]->__toString());
				}
			}


			$resultado2 = array();
			foreach ($resultado as $key => $row) {
				$row["convRate"] = number_format($row["convRate"] / $row["qtd"], 2, '.', ',') . "%";
				$row["ctr"] = number_format($row["ctr"] / $row["qtd"], 2, '.', ',') . "%";
				// $row["avgPosition"] = number_format($row["avgPosition"] / $row["qtd"], 1,'.',',');
				// $row["imprAbsTop"] = ($row["imprAbsTop"] == "1.0") ? str_replace('.', '', $row["imprAbsTop"]) : substr($row["imprAbsTop"],2);
				// $row["imprTop"] = ($row["imprTop"] == "1.0") ? str_replace('.', '', $row["imprTop"]) : substr($row["imprTop"],2);

				if ($consultoria) {
					$avgCPC = floatval($row["avgCPC"]) / $row["qtd"] / 1000000;
					$avgCPC = number_format($avgCPC, 2);
					$cost = floatval($row["cost"]) / 1000000;
					$cost = number_format($cost, 2);
					$row["cost"] = $cost;
					$row["avgCPC"] = $avgCPC;
				}

				$row["period-time"] = strtotime($key);
				$row["period"] = $key . " 0:00:00";

				$resultado2[] = $row;
			}

			$resultado = $resultado2;
		} else {
			// Preparamos aqui os dados para serem utilizados no JSON
			foreach ($rows as $row) {
				$linha = array(
					"impressions" => $row["impressions"]->__toString(),
					"clicks" => $row["clicks"]->__toString(),
					"invalid" => $row["invalidClicks"]->__toString(),
					"convertedClicks" => $row["conversions"]->__toString(),
					"convRate" => $row["convRate"]->__toString(),
					"ctr" => $row["ctr"]->__toString(),
					// "avgPosition" => $row["avgPosition"]->__toString()
				);

				// Caso o cliente seja de consultoria, adicionamos os campos de custo e cpc
				if ($consultoria) {
					$avgCPC = floatval(intval($row["avgCPC"]->__toString())) / 1000000;
					$avgCPC = number_format($avgCPC, 2);
					$cost = floatval(intval($row["cost"]->__toString())) / 1000000;
					$cost = number_format($cost, 2);
					$linha["avgCPC"] = $avgCPC;
					$linha["cost"] = $cost;
				}

				// Colocamos o período na array de resultado
				if ($periodo == "semanalmente")
					$linha["period"] = $row["week"]->__toString();
				else if ($periodo == "mensalmente")
					$linha["period"] = $row["month"]->__toString();
				else
					$linha["period"] = $row["day"]->__toString();
				$linha["period-time"] = strtotime($linha["period"]);

				// Adicionamos o tempo de meio-dia na data, para que o gráfico seja desenhado corretamente
				$linha["period"] .= " 0:00:00";

				$resultado[] = $linha;
			}
		}

		usort($resultado, function ($a, $b) {
			return $a["period-time"] - $b["period-time"];
		});


		return $resultado;
	}

	/* Formata o número especificado utilizando padrões do adwords */
	static function formatar_numero($numero)
	{
		return number_format($numero->__toString(), 0, ',', '.');
	}

	/* Formata o a quantidade monetária especificada utilizando padrões do adwords */
	static function formatar_valor($numero, $convencao = 0)
	{
		switch ($convencao) {
			case Sistema::MOEDA_REAL:
				$valor = floatval(strval($numero)) / 1000000;
				$valor = 'R$ ' . number_format($valor, 2, ',', '.');
				return $valor;
			case Sistema::MOEDA_DOLAR:
				$valor = floatval(intval(strval($numero))) / 1000000;
				$valor = '$ ' . number_format($valor, 2, '.', ',');
				return $valor;
			case Sistema::MOEDA_EURO:
				$valor = floatval(intval(strval($numero))) / 1000000;
				$valor = '€ ' . number_format($valor, 2, '.', ',');
				return $valor;
			default:
				return "";
		}
	}

	/* Formata o a quantidade monetária especificada utilizando padrões do adwords */
	static function formatar_valor_sem_icone_moeda($numero)
	{
		$valor = floatval(strval($numero)) / 1000000;
		$valor = number_format($valor, 2);
		return $valor;
	}

	/* Calcula o custo por lead */
	static function calcular_custo_lead($numero, $leads, $convencao = 0)
	{
		switch ($convencao) {
			case Sistema::MOEDA_REAL:
				$valor = floatval(strval($numero)) / 1000000;
				if ($leads > 0) $valor /= $leads;
				$valor2 = 'R$ ' . number_format($valor, 2, ',', '.');
				return array($valor, $valor2);
			case Sistema::MOEDA_DOLAR:
				$valor = floatval(intval(strval($numero))) / 1000000;
				if ($leads > 0) $valor /= $leads;
				$valor2 = '$ ' . number_format($valor, 2, '.', ',');
				return array($valor, $valor2);
			case Sistema::MOEDA_EURO:
				$valor = floatval(intval(strval($numero))) / 1000000;
				if ($leads > 0) $valor /= $leads;
				$valor2 = '€ ' . number_format($valor, 2, '.', ',');
				return array($valor, $valor2);
			default:
				return array("", "");
		}
	}

	/* Calcula o custo por lead */
	static function calcular_custo_lead_sem_icone_moeda($numero, $leads)
	{
		$valor = floatval(strval($numero)) / 1000000;
		if ($leads > 0) $valor /= $leads;
		$valor2 = number_format($valor, 2);
		return array($valor, $valor2);
	}

	/* Verifica se o usuário está acessando a página e bloqueia o IP dele no adwords no primeiro acesso */
	function verificar_bloqueio_ip_e_bloquear_instantaneo($id_cliente){

		error_reporting(0);
		ignore_user_abort(true);
		session_name("adwordsbloqueionahora" . $id_cliente);
		session_start();

		try {
			$dados = $this->bd->executar("SELECT NU_ADWORDS FROM TBL_CLIENTE WHERE ID_CLIENTE = :id", array(':id' => $id_cliente), Banco_Dados::FETCH);
			$id_do_adwords = $dados['NU_ADWORDS'];
			if (empty($id_do_adwords)) {
				return;
			}

			$detect = new MobileDetect();

			/* Pega o IP do Usuário */
			$ip = empty($_SERVER['HTTP_CLIENT_IP']) ?
				(empty($_SERVER['HTTP_X_FORWARDED_FOR']) ?
					$_SERVER['REMOTE_ADDR']
					: $_SERVER['HTTP_X_FORWARDED_FOR'])
				: $_SERVER['HTTP_CLIENT_IP'];

			/* Pega os horarios e verifica se esta acessando muito rapido */
			if (empty($_SESSION['hora'])) $_SESSION['hora'] = date('H:i:s');
			$horaAtual = date('H:i:s');
			$data1 = new DateTime($horaAtual);
			$horaUltimoAcesso = $_SESSION['hora'];
			$data2 = new DateTime($horaUltimoAcesso);
			$intervalo = $data1->diff($data2);

			/* Conta os acesso a pagina */
			if (empty($_SESSION['contador'])) $_SESSION['contador'] = 0;
			$_SESSION['contador'] += 1;

			/* Calcula os segundos do ultimo acesso e a quantidade de acessos */
			// if (($intervalo->s < $segundos_bloqueio && $intervalo->i < 1 && $_SESSION['contador'] > 1) || $_SESSION['contador'] > $qtd_cliques_max) { /* 10 segundos ou mais que 4 acessos */

				$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
				if ($ip != $IPBloqueado) {
					/* Executa funcao para salvar IP no banco */
					$this->salvar_ip_banco($ip, $id_cliente, $horaAtual, $interv = $intervalo->i . " min e " . $intervalo->s, $_SESSION['contador']);

					try {
						/* Chama a funcao para adiciona o IP na lista da IP Bloqueados do AdWords */
						$this->bloquear_ip($id_cliente, $ip);
					} catch (Exception $e) {
						$this->salvar_erro_ip_banco('Erro #1: ' . $e->getMessage(), $id_cliente);
					}
				}
			// }

			/* Se existir o IP no Banco, ele altera a quantidade de acessos */
			$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
			if ($ip == $IPBloqueado) {
				/* Salva a quantidade de acessos */
				$this->salvar_qtd_tentativas_ip($_SESSION['contador'], $ip);
			}

			/* Salva se for MOBILE */
			if ($detect->isMobile()) {
				$dispositivo = "Smartphone";
			}

			/* Salva se for TABLET */
			if ($detect->isTablet()) {
				$dispositivo = "Tablet";
			}

			/* Salva se não for MOBILE nem TABLET */
			if (!$detect->isMobile() && !$detect->isTablet()) {
				$dispositivo = "Computador";
			}

			/* Chama a funcao para salvar o dispositivo */
			$this->salvar_dispositivo_ip($dispositivo, $ip);

			/* Pega o IP Acessado */
			$_SESSION['ultimoIPAcessado'] = $ip;

			/* Pega a hora atual acessada */
			$_SESSION['hora'] = date('H:i:s');
		} catch (Exception $e) {}
	}

	/* Verifica se o usuário está acessando a página com muita frequência, e bloqueia o IP dele no adwords caso esteja */
	function verificar_bloqueio_ip($id_cliente, $qtd_cliques_max = 2, $segundos_bloqueio = 600)
	{ /* 600 = 10 min */
		error_reporting(0);
		ignore_user_abort(true);
		session_name("adwords" . $id_cliente);
		session_start();

		try {
			$dados = $this->bd->executar("SELECT NU_ADWORDS FROM TBL_CLIENTE WHERE ID_CLIENTE = :id", array(':id' => $id_cliente), Banco_Dados::FETCH);
			$id_do_adwords = $dados['NU_ADWORDS'];
			if (empty($id_do_adwords)) {
				return;
			}

			$detect = new MobileDetect();

			/* Pega o IP do Usuário */
			$ip = empty($_SERVER['HTTP_CLIENT_IP']) ?
				(empty($_SERVER['HTTP_X_FORWARDED_FOR']) ?
					$_SERVER['REMOTE_ADDR']
					: $_SERVER['HTTP_X_FORWARDED_FOR'])
				: $_SERVER['HTTP_CLIENT_IP'];

			/* Pega os horarios e verifica se esta acessando muito rapido */
			if (empty($_SESSION['hora'])) $_SESSION['hora'] = date('H:i:s');
			$horaAtual = date('H:i:s');
			$data1 = new DateTime($horaAtual);
			$horaUltimoAcesso = $_SESSION['hora'];
			$data2 = new DateTime($horaUltimoAcesso);
			$intervalo = $data1->diff($data2);

			/* Conta os acesso a pagina */
			if (empty($_SESSION['contador'])) $_SESSION['contador'] = 0;
			$_SESSION['contador'] += 1;

			/* Calcula os segundos do ultimo acesso e a quantidade de acessos */
			if (($intervalo->s < $segundos_bloqueio && $intervalo->i < 1 && $_SESSION['contador'] > 1) || $_SESSION['contador'] > $qtd_cliques_max) { /* 10 segundos ou mais que 4 acessos */

				$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
				if ($ip != $IPBloqueado) {
					/* Executa funcao para salvar IP no banco */
					$this->salvar_ip_banco($ip, $id_cliente, $horaAtual, $interv = $intervalo->i . " min e " . $intervalo->s, $_SESSION['contador']);

					try {
						/* Chama a funcao para adiciona o IP na lista da IP Bloqueados do AdWords */
						$this->bloquear_ip($id_cliente, $ip);
					} catch (Exception $e) {
						$this->salvar_erro_ip_banco('Erro #1: ' . $e->getMessage(), $id_cliente);
					}
				}
			}

			/* Se existir o IP no Banco, ele altera a quantidade de acessos */
			$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
			if ($ip == $IPBloqueado) {
				/* Salva a quantidade de acessos */
				$this->salvar_qtd_tentativas_ip($_SESSION['contador'], $ip);
			}

			/* Salva se for MOBILE */
			if ($detect->isMobile()) {
				$dispositivo = "Smartphone";
			}

			/* Salva se for TABLET */
			if ($detect->isTablet()) {
				$dispositivo = "Tablet";
			}

			/* Salva se não for MOBILE nem TABLET */
			if (!$detect->isMobile() && !$detect->isTablet()) {
				$dispositivo = "Computador";
			}

			/* Chama a funcao para salvar o dispositivo */
			$this->salvar_dispositivo_ip($dispositivo, $ip);

			/* Pega o IP Acessado */
			$_SESSION['ultimoIPAcessado'] = $ip;

			/* Pega a hora atual acessada */
			$_SESSION['hora'] = date('H:i:s');
		} catch (Exception $e) {
		}
	}

	/* Verifica se o usuário está acessando a página com muita frequência, e bloqueia o IP dele no adwords caso esteja */
	function verificar_bloqueio_ip_umacesso($id_cliente, $qtd_cliques_max = 0, $segundos_bloqueio = 0)
	{
		error_reporting(0);
		ignore_user_abort(true);
		session_name("adwords" . $id_cliente);
		session_start();

		try {
			$dados = $this->bd->executar("SELECT NU_ADWORDS FROM TBL_CLIENTE WHERE ID_CLIENTE = :id", array(':id' => $id_cliente), Banco_Dados::FETCH);
			$id_do_adwords = $dados['NU_ADWORDS'];
			if (empty($id_do_adwords)) {
				return;
			}

			$detect = new MobileDetect();

			/* Pega o IP do Usuário */
			$ip = empty($_SERVER['HTTP_CLIENT_IP']) ?
				(empty($_SERVER['HTTP_X_FORWARDED_FOR']) ?
					$_SERVER['REMOTE_ADDR']
					: $_SERVER['HTTP_X_FORWARDED_FOR'])
				: $_SERVER['HTTP_CLIENT_IP'];

			/* Pega os horarios e verifica se esta acessando muito rapido */
			if (empty($_SESSION['hora'])) $_SESSION['hora'] = date('H:i:s');
			$horaAtual = date('H:i:s');
			$data1 = new DateTime($horaAtual);
			$horaUltimoAcesso = $_SESSION['hora'];
			$data2 = new DateTime($horaUltimoAcesso);
			$intervalo = $data1->diff($data2);

			/* Conta os acesso a pagina */
			if (empty($_SESSION['contador'])) $_SESSION['contador'] = 0;
			$_SESSION['contador'] += 1;

			/* Calcula os segundos do ultimo acesso e a quantidade de acessos */
			if (($intervalo->s < $segundos_bloqueio && $intervalo->i < 1 && $_SESSION['contador'] > 0) || $_SESSION['contador'] > $qtd_cliques_max) { /* 10 segundos ou mais que 4 acessos */

				$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
				if ($ip != $IPBloqueado) {
					/* Executa funcao para salvar IP no banco */
					$this->salvar_ip_banco($ip, $id_cliente, $horaAtual, $interv = $intervalo->i . " min e " . $intervalo->s, $_SESSION['contador']);

					try {
						/* Chama a funcao para adiciona o IP na lista da IP Bloqueados do AdWords */
						$this->bloquear_ip($id_cliente, $ip);
					} catch (Exception $e) {
						$this->salvar_erro_ip_banco('Erro #1: ' . $e->getMessage(), $id_cliente);
					}
				}
			}

			/* Se existir o IP no Banco, ele altera a quantidade de acessos */
			$IPBloqueado = $this->buscar_ip_banco($id_cliente, $ip);
			if ($ip == $IPBloqueado) {
				/* Salva a quantidade de acessos */
				$this->salvar_qtd_tentativas_ip($_SESSION['contador'], $ip);
			}

			/* Salva se for MOBILE */
			if ($detect->isMobile()) {
				$dispositivo = "Smartphone";
			}

			/* Salva se for TABLET */
			if ($detect->isTablet()) {
				$dispositivo = "Tablet";
			}

			/* Salva se não for MOBILE nem TABLET */
			if (!$detect->isMobile() && !$detect->isTablet()) {
				$dispositivo = "Computador";
			}

			/* Chama a funcao para salvar o dispositivo */
			$this->salvar_dispositivo_ip($dispositivo, $ip);

			/* Pega o IP Acessado */
			$_SESSION['ultimoIPAcessado'] = $ip;

			/* Pega a hora atual acessada */
			$_SESSION['hora'] = date('H:i:s');
		} catch (Exception $e) {
		}
	}


	/* Salva os possíveis erros no banco */
	function salvar_erro_ip_banco($erro, $id)
	{
		try {
			/* Conecta com o banco para inserir os dados */
			$this->bd->executar(
				'UPDATE TBL_IP_ADWORDS SET ERRO = :ERRO WHERE ID_CLIENTE = :ID_CLIENTE',
				array(
					':ERRO' => $erro,
					':ID_CLIENTE' => $id
				)
			);
			return true;
		} catch (Exception $e) {
			return false;
		}
	}

	/* Funcao para buscar o IP no banco, para ver se ele existe */
	function buscar_ip_banco($id, $ip)
	{
		try {
			$IPBanco = "";

			/* Conecta com o banco para inserir os dados */
			$dados = $this->bd->executar("SELECT IP FROM TBL_IP_ADWORDS WHERE ID_CLIENTE = '$id' AND IP = '$ip' ", array(), Banco_Dados::FETCH_ALL);
			$qtde = count($dados);
			if ($qtde > 0) {
				foreach ($dados as $row) {
					$IPBanco = $row['IP'];
				}
			}
			return $IPBanco;
		} catch (Exception $e) {
			return false;
		}
	}

	/* Funcao para salvar IP no Banco */
	function salvar_ip_banco($ip, $id, $horaAtual, $interv, $tentativaAtual)
	{
		try {
			/* Conecta com o banco para inserir os dados */
			$this->bd->executar(
				'INSERT INTO TBL_IP_ADWORDS (IP,ID_CLIENTE,HORA_ACESSO,INTERVALO,TENTATIVA) VALUES (:IP,:ID_CLIENTE,:HORA_ACESSO,:INTERVALO,:TENTATIVA)',
				array(
					':IP'  => $ip,
					':ID_CLIENTE' => $id,
					':HORA_ACESSO' => $horaAtual,
					':INTERVALO' => $interv,
					':TENTATIVA' => $tentativaAtual
				)
			);
			return true;
		} catch (Exception $e) {
			return false;
		}
	}

	/* Salva a quantidade de tentativas de acesso */
	function salvar_qtd_tentativas_ip($tentativas, $ip)
	{
		try {
			$this->bd->executar(
				'UPDATE TBL_IP_ADWORDS SET QTD_TENTATIVAS = :QTD_TENTATIVAS WHERE IP = :IP',
				array(
					':QTD_TENTATIVAS' => $tentativas,
					':IP' => $ip
				)
			);
			return true;
		} catch (Exception $e) {
			return false;
		}
	}

	/* Salva a quantidade de tentativas de acesso */
	function salvar_dispositivo_ip($dispositivo, $ip)
	{
		try {
			/* Conecta com o banco para inserir os dados */
			$this->bd->executar(
				'UPDATE TBL_IP_ADWORDS SET DISPOSITIVO = :DISPOSITIVO WHERE IP = :IP',
				array(
					':DISPOSITIVO' => $dispositivo,
					':IP' => $ip
				)
			);

			return true;
		} catch (Exception $e) {
			return false;
		}
	}
}

class Credenciais_Adwords
{
	public $sessao;
	public $oauth2;
}
